@@ -8,7 +8,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.787';
+our $VERSION = '0.788';
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -37,7 +37,7 @@ sub should_inline_value
 {
   my($self, $db, $value) = @_;
   no warnings 'uninitialized';
-  return (($db->validate_set_keyword($value) && $db->should_inline_set_keywords) ||
+  return (($db->validate_set_keyword($value) && $db->should_inline_set_keyword($value)) ||
           ($db->keyword_function_calls && $value =~ /^\w+\(.*\)$/)) ? 1 : 0;
 }
 
